@@ -1,9 +1,6 @@
 #include <sys/queue.h>
-#ifdef _ALLOCA_H
 #include <alloca.h>
-#else
 #include <limits.h>
-#endif
 #include <ctype.h>
 #include <dirent.h>
 #include <errno.h>
@@ -51,6 +48,10 @@ static acl_t prev_acl = NULL;
 #define STATEFILE_BUFFER_SIZE 4096
 #endif
 
+#ifdef __hpux
+extern int asprintf(char **str, const char *fmt, ...);
+#endif
+
 struct logState {
     char *fn;
     struct tm lastRotated;	/* only tm.mon, tm_mday, tm_year are good! */
@@ -413,13 +414,15 @@ static int compressLogFile(char *name, struct logInfo *log, struct stat *sb)
 	}
 	if (prev_acl) {
 		if (acl_set_fd(outFile, prev_acl) == -1) {
-			message(MESS_ERROR, "setting ACL for %s: %s\n",
-			compressedName, strerror(errno));
-			acl_free(prev_acl);
-			prev_acl = NULL;
-			close(inFile);
-			close(outFile);
-			return 1;
+			if (errno != ENOTSUP) {
+				message(MESS_ERROR, "setting ACL for %s: %s\n",
+				compressedName, strerror(errno));
+				acl_free(prev_acl);
+				prev_acl = NULL;
+				close(inFile);
+				close(outFile);
+				return 1;
+			}
 		}
 		acl_free(prev_acl);
 		prev_acl = NULL;
@@ -627,14 +630,16 @@ static int copyTruncate(char *currLog, char *saveLog, struct stat *sb,
 	}
 #ifdef WITH_ACL
 	if (prev_acl) {
-		if (acl_set_fd(fdsave, prev_acl) == -1) {
-			message(MESS_ERROR, "setting ACL for %s: %s\n",
-			saveLog, strerror(errno));
-			acl_free(prev_acl);
-			prev_acl = NULL;
-			close(fdsave);
-			close(fdcurr);
-			return 1;
+		if ((fdsave, prev_acl) == -1) {
+			if (errno != ENOTSUP) {
+				message(MESS_ERROR, "setting ACL for %s: %s\n",
+				saveLog, strerror(errno));
+				acl_free(prev_acl);
+				prev_acl = NULL;
+				close(fdsave);
+				close(fdcurr);
+				return 1;
+			}
 		}
 		acl_free(prev_acl);
 		prev_acl = NULL;
@@ -787,6 +792,9 @@ int findNeedRotating(struct logInfo *log, int logNum)
 	    state->doRotate = 0;
     }
 
+    if (log->maxsize && sb.st_size > log->maxsize)
+        state->doRotate = 1;
+
     /* The notifempty flag overrides the normal criteria */
     if (!(log->flags & LOG_FLAG_IFEMPTY) && !sb.st_size)
 	state->doRotate = 0;
@@ -1153,6 +1161,8 @@ int prerotateSingleLog(struct logInfo *log, int logNum, struct logState *state,
 		    hasErrors = 1;
 		}
 	    }
+	    if (hasErrors || i - 1 < 0)
+		    free(oldName);
 	    
 	}
 	free(newName);
@@ -1332,9 +1342,11 @@ int rotateSingleLog(struct logInfo *log, int logNum, struct logState *state,
 #ifdef WITH_ACL
 				if (prev_acl) {
 					if (acl_set_fd(fd, prev_acl) == -1) {
-						message(MESS_ERROR, "setting ACL for %s: %s\n",
-						log->files[logNum], strerror(errno));
-						hasErrors = 1;
+						if (errno != ENOTSUP) {
+							message(MESS_ERROR, "setting ACL for %s: %s\n",
+							log->files[logNum], strerror(errno));
+							hasErrors = 1;
+						}
 					}
 					acl_free(prev_acl);
 					prev_acl = NULL;
@@ -1460,6 +1472,9 @@ int rotateLogSet(struct logInfo *log, int force)
     if (log->minsize) 
 	message(MESS_DEBUG, "only log files >= %llu bytes are rotated, ",	log->minsize);
 
+    if (log->maxsize) 
+	message(MESS_DEBUG, "log files >= %llu are rotated earlier, ",	log->minsize);
+
     if (log->logAddress) {
 	message(MESS_DEBUG, "old logs mailed to %s\n", log->logAddress);
     } else {
